// DndKit documentation: https://docs.dndkit.com/
import { useSortable } from '@dnd-kit/sortable'
import { CSS } from '@dnd-kit/utilities'

// via-ui
import { Card, CardContent, CardHeader } from '../ui/card'
import { Badge } from '../ui/badge'

// Others
import { cva } from 'class-variance-authority'
import { TaskCardProps, TaskDragData } from './taskCard.types'
import { useScreenType } from '../../hooks'

export const TaskCard = ({
  task,
  isOverlay,
  renderHeader,
  renderContent
}: TaskCardProps) => {
  const screenType = useScreenType()

  const {
    setNodeRef,
    attributes,
    listeners,
    transform,
    transition,
    isDragging
  } = useSortable({
    id: task.id,
    data: {
      type: 'Task',
      task
    } satisfies TaskDragData,
    attributes: {
      roleDescription: 'Task'
    }
  })

  const style = {
    transition,
    transform: CSS.Translate.toString(transform)
  }

  const variants = cva(
    'rounded-xl border border-transparent bg-white shadow-md hover:border-gray-200',
    {
      variants: {
        dragging: {
          over: 'opacity-30 ring-2',
          overlay: 'rotate-2 bg-white/60 ring-2 ring-black'
        },
        screenType: {
          desktop: '',
          mobile: 'w-full'
        }
      }
    })

  return (
    <Card
      {...attributes}
      {...listeners}
      ref={setNodeRef}
      style={style}
      className={ variants({
        dragging: isOverlay ? 'overlay' : isDragging ? 'over' : undefined,
        screenType: screenType.isMobile ? 'mobile' : 'desktop'
      })}
    >
      <CardHeader
        className="relative flex flex-row border-b-2 p-2"
      >
        {renderHeader
          ? renderHeader(task)
          : (
            <Badge variant={'outline'} className="font-semibold hover:border-gray-700">
              {task.id}
            </Badge>
          )}
      </CardHeader>
      <CardContent className="whitespace-pre-wrap px-3 pb-6 pt-3 text-left">
        {renderContent ? renderContent(task) : task.content}
      </CardContent>
    </Card>
  )
}
