import React from 'react'
import PropTypes from 'prop-types'
import { Calendar, momentLocalizer } from 'react-big-calendar'
import moment from 'moment'
import Toolbar from 'react-big-calendar/lib/Toolbar'
import { FaCalendarDay, FaChevronLeft, FaChevronRight } from 'react-icons/fa'
import { DocumentPlusIcon } from '@heroicons/react/24/solid'

VCalendar.PropTypes = {
  children: PropTypes.node,
  name: PropTypes.string,
  headers: PropTypes.array,
  events: PropTypes.array,
  model: PropTypes.object,
  isEdit: PropTypes.bool,
  onSave: PropTypes.func,
  onCancel: PropTypes.func,
  reactBigCalendar: PropTypes.func,
  onSuccessUpload: PropTypes.func,
  tooblar: PropTypes.object,
  showSaveNew: PropTypes.bool,
  showCancel: PropTypes.bool,
  cols: PropTypes.number,
  i18n: PropTypes.object,
  presets: PropTypes.object
}

VCalendar.defaultProps = {
  children: null,
  name: '',
  headers: [],
  events: [],
  model: {},
  isEdit: false,
  onSave: () => {},
  onCancel: () => {},
  reactBigCalendar: () => {},
  onSuccessUpload: () => {},
  tooblar: {},
  showSaveNew: true,
  showCancel: true,
  cols: 1,
  i18n: {},
  presets: {}
}

export default function VCalendar ({ children, name, headers, events, model, isEdit, onSave, onCancel, onSuccessUpload, showSaveNew = true, showCancel = true, cols = 1, i18n = { t: () => { return 'txtNone' } }, presets }) {
  moment.locale('es', {
    month: {
      dow: 1 // for starrting day from monday
    }
  })
  const localizer = momentLocalizer(moment)
  const views = ['day', 'week', 'month', 'agenda']

  const EventComponent = ({ events, change }) => (props) => {
    // console.log('change', events, change)
    return (
      <div title={props.event.title}>
        <h1 >{props.event.title}</h1>
        <h4>{props.event.observaciones}</h4>
        {/* <button onClick={props.change}>Do Something</button> */}
      </div>
    )
  }

  const handleDayChange = (event, mconte) => {
    mconte(event.target.value)
  }
  const handleNamvigate = (detail, elem) => {
    detail.navigate(elem)
  }

  const CustomToolbar = ({ handleChange }) => {
    return class BaseToolBar extends Toolbar {
      constructor (props) {
        super(props)
      }

      handleDayChange = (event, mconte) => {
        mconte(event.target.value)
      }

      handleNamvigate = (detail, elem) => {
        detail.navigate(elem)
      }

      handleNavigateToEvent = () => {
        onSave()
      }

      render () {
        return (
          <div className="grid grid-cols-2 content-start gap-1 p-2 md:grid-cols-5">
            {/* <!-- Primera fila --> */}
            <div classNames="col-span-1  flex justify-start md:flex md:justify-end">
              <button
                type="button"
                className="via-button flex items-center border-2 border-blue-600 !bg-blue-500 px-8 text-white transition-colors duration-500 ease-in-out hover:!bg-blue-400"
                onClick={() => this.handleNamvigate(this, 'TODAY')}
              >
                <FaCalendarDay className="mr-2 shrink-0" /> Today
              </button>
            </div>

            <div className="col-span-1  flex justify-end md:flex md:justify-start">
              <button
                type="button"
                className="via-button flex w-auto items-center justify-center border-2 border-blue-600 !bg-blue-500 px-3 transition-colors duration-500 ease-in-out hover:!bg-blue-400"
                onClick={() => this.handleNamvigate(this, 'PREV')}
              >
                <FaChevronLeft className="mr-2 shrink-0 !text-white" />
              </button>
              <button
                type="button"
                className="via-button flex w-auto items-center justify-center border-2 border-blue-600 !bg-blue-500 px-3 transition-colors duration-500 ease-in-out hover:!bg-blue-400"
                onClick={() => this.handleNamvigate(this, 'NEXT')}
              >
                <FaChevronRight className="mr-2 shrink-0 !text-white"/>
              </button>
            </div>

            {/* <!-- Segunda fila --> */}
            <div className="col-span-2 flex items-center justify-center font-semibold md:col-span-1 ">
              <label>{this.props.label}</label>
            </div>

            {/* <!-- Tercera fila --> */}
            <div className="col-span-1  content-end">
              <select
                className=" bg-white via-input text-base font-normal text-gray-700  transition ease-in-out focus:border-blue-600 focus:bg-white focus:text-gray-700 focus:outline-none"
                aria-label="Default select example"
                onChange={(e) => this.handleDayChange(e, this.view)}
                defaultValue={'week'}
              >
                <option value="day">Day</option>
                <option value="week">Week</option>
                <option value="month">Month</option>
                <option value="agenda">Agenda</option>
              </select>
            </div>

            {/* <!-- Cuarta fila --> */}
            <div className="col-span-1 flex justify-end">
              <button
                onClick={this.handleNavigateToEvent}
                className=" via-button bg-emerald-500 px-6 text-gray-100 transition duration-150 hover:bg-emerald-800"
              >
                <DocumentPlusIcon className="mr-2 h-6 w-6 shrink-0 text-white"/>
                  Nuevo
              </button>
            </div>
          </div>
        )
      }
    }
  }

  const eventStyleGetter = (event, start, end, isSelected) => {
    const backgroundColor = '#' + Math.floor(Math.random() * 16777215).toString(16)
    const style = {
      backgroundColor: event.color ? event.color : backgroundColor,
      borderRadius: '5px',
      opacity: 1,
      color: 'white',
      border: '5px',
      display: 'block'
    }
    return {
      style
    }
  }
  const handleNavigation = (date, view, action) => {
    console.log(date, view, action)
    // it returns current date, view options[month,day,week,agenda] and action like prev, next or today
  }
  const handleEventSelection = (e) => {
    console.log(e)
  }

  const handleChange = () => {
    console.log(true)
  }

  const openPopupForm = (slotInfo) => {
    console.log(true)
  }

  const onSelectEventSlotHandler = (slotInfo) => {
    openPopupForm(slotInfo) // OPEN POPUP FOR CREATE/EDIT EVENT
  }

  const change = handleChange
  return (
    <div>

      <Calendar
        localizer={localizer}
        selectable={true}
        formats={{
          dayHeaderFormat: (date, culture, localizer) =>
            localizer.format(date, 'dddd D', culture)
        }}
        dayLayoutAlgorithm="no-overlap"
        dayStyle={{
          backgroundColor: '#fff', // Fondo blanco para la vista de día
          borderBottom: '2px solid #ddd', // Línea de separación entre días
          padding: '10px', // Ajusta el relleno para un aspecto más espaciado
          boxShadow: '0 0 5px rgba(0, 0, 0, 0.1)', // Sombra suave
          borderRadius: '5px' // Bordes redondeados
        }}
        views={views}
        events={events}
        style={{ height: 600 }}
        showMultiDayTimes
        onSelectSlot={event => { onSelectEventSlotHandler(event) }}
        culture={['es']}
        onNavigate={handleNavigation}
        onSelectEvent={handleEventSelection}
        components={{
          event: EventComponent({ events, change }),
          // data as events array and change is custom method passed into component(for perform any functionality on parent state)
          toolbar: CustomToolbar({ events, change })
        }}
        eventPropGetter={(eventStyleGetter)}
        // onSelectSlot={(slotInfo) => onSelectEventSlotHandler(slotInfo)}
      />
    </div>)
}
