import { RouteProvider } from '@/hooks/useRoute'
import { useStore } from '@/hooks/useStore'
import ResponsiveContainer from '@/layout/ResponsiveContainer'
import LoadingProvider from '@/plugins/LoadingContext'
import I18nProvider from '@/plugins/i18nContext'
import Head from 'next/head'
import { ToastContainer } from 'react-toastify'

import '@/styles/globals.css'
import 'vComponents/styles/generated/bgColors.min.css'
import 'vComponents/styles/generated/output.css'

export default function App ({ Component, pageProps }) {
  const [theme] = useStore(s => s.theme, a => a.setTheme)

  return (
    <>
      <Head>
        <link rel="icon" href="https://wiki.via-asesores.com/logo-orbis_min.png" type="image/x-icon" />
        <title>Orbis Playground</title>
      </Head>

      <I18nProvider locale={'es'} dict={''}>
        <LoadingProvider>
          <ResponsiveContainer>
            <ToastContainer
              theme={theme === 'dark' ? 'dark' : 'light'}
              toastClassName={theme === 'dark'
                ? 'bg-black shadow-neon text-white rounded-lg'
                : 'bg-white text-black drop-shadow-lg rounded-lg shadow-lg'}
            />
            <RouteProvider>
              <Component {...pageProps} />
            </RouteProvider>
          </ResponsiveContainer>
        </LoadingProvider>
      </I18nProvider>
    </>
  )
}
