import CodePlayground from '@/components/CodePlayground'
import React, { useState } from 'react'
import { Stepper, StepperList, StepperTrigger, StepContent, StepLabel } from 'via-ui/stepper'

const initialCode = `
// import { Stepper, StepperList, StepperTrigger, StepContent, StepLabel, Button } from 'via-ui/stepper'

const StepperExample = () => {
  const [activeStep, setActiveStep] = useState('step1');
  const steps = ['step1', 'step2', 'step3'];

  const handleStepChange = (step) => {
    setActiveStep(step);
  };

  const handleNext = () => {
    const currentIndex = steps.indexOf(activeStep);
    if (currentIndex < steps.length - 1) {
      setActiveStep(steps[currentIndex + 1]);
    }
  };

  const handleBack = () => {
    const currentIndex = steps.indexOf(activeStep);
    if (currentIndex > 0) {
      setActiveStep(steps[currentIndex - 1]);
    }
  };

  return (
    <Stepper activeStep={activeStep}>
      <StepperList>
        {steps.map((step) => (
          <StepperTrigger
            key={step}
            value={step}
            onStepChange={() => handleStepChange(step)}
            isClickable={true}
          >
            <StepLabel>{'Step ' + (steps.indexOf(step) + 1)}</StepLabel>
          </StepperTrigger>
        ))}
      </StepperList>

      <StepContent value={activeStep}>
        <p>{'Content for ' + activeStep}</p>
        <div style={{ display: 'flex', justifyContent: 'space-between' }}>
          <button className='via-button bg-blue-500 text-white' onClick={handleBack} disabled={activeStep === steps[0]}>
            Atrás
          </button>
          <button className='via-button bg-green-500 text-white' onClick={handleNext} disabled={activeStep === steps[steps.length - 1]}>
            Adelante
          </button>
        </div>
      </StepContent>
    </Stepper>
  );
};

render(<StepperExample />);
`

const ExampleComponentPage = () => {
  const [code, setCode] = useState(initialCode)

  // El objeto scope debería incluir todos los componentes y funciones que el código JSX necesita
  const scope = {
    React,
    useState,
    Stepper,
    StepperList,
    StepperTrigger,
    StepContent,
    StepLabel
  }

  return (
    <>
      <div className='rounded-lg bg-white p-4 shadow-lg dark:!bg-[#222222]'>
        <CodePlayground code={code} onChange={(newCode) => { setCode(newCode) }} scope={scope} />
      </div>
    </>
  )
}

export default ExampleComponentPage
